%define gettext_package dbus

%define expat_version      2.0.0
%define libxml2_version    2.6.26
%define glib_version       2.12.1
%define qt_version         3.3.7
%define gtk_version        2.8.6
%define libselinux_version 1.34

%define dbus_user_uid      81

%global momorel 1

Summary: D-BUS message bus
Name: dbus
Version: 1.2.4
Release: %{momorel}m%{?dist}
URL: http://www.freedesktop.org/software/dbus/
Source0: http://dbus.freedesktop.org/releases/%{name}/%{name}-%{version}.tar.gz 
NoSource: 0
Source1: doxygen_to_devhelp.xsl
Source2: 00-start-message-bus.sh
License: "AFL/GPL"
Group: System Environment/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
PreReq: chkconfig shadow-utils initscripts
BuildPreReq: libtool
BuildRequires: expat-devel >= %{expat_version}
BuildRequires: Pyrex       >= 0.9.4
BuildRequires: libselinux-devel >= %{libselinux_version}
BuildRequires: audit-libs-devel >= 1.3.1
BuildRequires: libX11-devel
BuildRequires: libcap-devel
BuildRequires: gettext
BuildRequires: doxygen
BuildRequires: xmlto
BuildRequires: libxslt

Requires: libselinux >= %{libselinux_version}
Requires: libxml2-python
Requires: chkconfig

# Conflict with cups prior to configuration file change, so that the
# %postun service condrestart works.
Conflicts: cups < 1.1.20

Patch0: start-early.patch
Patch1: dbus-1.0.1-generate-xml-docs.patch
Patch2: dbus-1.2.1-increase-timeout.patch

%description

D-BUS is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package libs
Summary: Libraries for accessing D-BUS
Group: Development/Libraries
Requires: %name = %{version}-%{release}
Obsoletes: dbus < 1.1.2-3

%description libs
Lowlevel libraries for accessing D-BUS

%package doc
Summary: Developer documentation for D-BUS
Group: Documentation
Requires: %name = %{version}-%{release}
Requires: devhelp

%description doc 
This package contains DevHelp developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file

%package devel
Summary: Libraries and headers for D-BUS
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel

Headers and static libraries for D-BUS.

%package x11
Summary: X11-requiring add-ons for D-BUS
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description x11

D-BUS contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%prep
%setup -q

# For some reason upstream ships these files as executable
# Make sure they are not
/bin/chmod 0644 COPYING ChangeLog NEWS

%patch0 -p1 -b .start-early
%patch1 -p1 -b .generate-xml-docs
%patch2 -p1 -b .increase-timeout

autoreconf -f -i -v

%build
COMMON_ARGS="--enable-libaudit --enable-selinux=yes --with-init-scripts=redhat --with-system-pid-file=%{_localstatedir}/run/messagebus.pid --with-dbus-user=dbus --libdir=/%{_lib} --bindir=/bin --sysconfdir=%{_sysconfdir} --exec-prefix=/ --libexecdir=/%{_lib}/dbus-1"

#### Build once with tests to make check
%configure $COMMON_ARGS --enable-tests=yes --enable-verbose-mode=yes --enable-asserts=yes -program-transform-name=""
DBUS_VERBOSE=1 make

#### Clean up and build again 
make clean 

# leave verbose mode so people can debug their apps but make sure to
# turn it off on stable releases with --disable-verbose-mode
%configure $COMMON_ARGS --disable-tests --disable-asserts --enable-doxygen-docs --enable-xml-docs -program-transform-name=""
make

doxygen Doxyfile

xsltproc -o dbus.devhelp %{SOURCE1} doc/api/xml/index.xml

%install
rm -rf --preserve-root %{buildroot}

make install DESTDIR=%{buildroot}

mkdir -p %{buildroot}/%{_libdir}/pkgconfig

# change the arch-deps.h include directory to /usr/lib[64] instead of /lib[64]
sed -e 's@-I${libdir}@-I${prefix}/%{_lib}@' %{buildroot}/%{_lib}/pkgconfig/dbus-1.pc > %{buildroot}%{_libdir}/pkgconfig/dbus-1.pc
rm -f %{buildroot}/%{_lib}/pkgconfig/dbus-1.pc

mkdir -p %{buildroot}%{_bindir}
mv -f %{buildroot}/bin/dbus-launch %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_libdir}/dbus-1.0/include/
mv -f %{buildroot}/%{_lib}/dbus-1.0/include/* %{buildroot}%{_libdir}/dbus-1.0/include/

rm -f %{buildroot}/%{_lib}/*.la

cp -a %{buildroot}%{_sysconfdir}/rc.d/* %{buildroot}%{_sysconfdir}/
rm -rf %{buildroot}%{_sysconfdir}/rc.d

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}

mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus/api

cp dbus.devhelp %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-specification.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-faq.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-tutorial.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/api/html/* %{buildroot}%{_datadir}/devhelp/books/dbus/api

install -D -m755 %{SOURCE2} %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

# for soprano and PolicyKit
mkdir -p %{buildroot}%{_datadir}/dbus-1/interfaces

%clean
rm -rf --preserve-root %{buildroot}

%pre
# Add the "dbus" user
%{_sbindir}/useradd -c 'System message bus' -u %{dbus_user_uid} \
	-s /sbin/nologin -r -d '/' dbus 2> /dev/null || :

%post
/sbin/chkconfig --add messagebus
/sbin/chkconfig messagebus resetpriorities

%post libs -p /sbin/ldconfig

%preun
if [ $1 = 0 ]; then
    service messagebus stop > /dev/null 2>&1
    /sbin/chkconfig --del messagebus
fi

%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING ChangeLog NEWS
%dir %{_sysconfdir}/dbus-1
%config %{_sysconfdir}/dbus-1/*.conf
%config %{_initscriptdir}/*
%dir %{_sysconfdir}/dbus-1/session.d
%dir %{_sysconfdir}/dbus-1/system.d
%dir %{_localstatedir}/run/dbus
%dir %{_localstatedir}/lib/dbus/
%dir /%{_lib}/dbus-1.0
/bin/dbus-daemon
/bin/dbus-send
/bin/dbus-cleanup-sockets
/bin/dbus-monitor
/bin/dbus-uuidgen
%{_datadir}/man/man*/dbus-cleanup-sockets.1*
%{_datadir}/man/man*/dbus-daemon.1*
%{_datadir}/man/man*/dbus-monitor.1*
%{_datadir}/man/man*/dbus-send.1*
%{_datadir}/man/man*/dbus-uuidgen.1*
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/system-services
%dir /%{_lib}/dbus-1
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%attr(4750,root,dbus) /%{_lib}/dbus-1/dbus-daemon-launch-helper

%files libs
%defattr(-,root,root,-)
/%{_lib}/*dbus-1*.so.*

%files x11
%defattr(-,root,root)
%{_bindir}/dbus-launch
%{_datadir}/man/man*/dbus-launch.1*
%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

%files doc
%defattr(-,root,root)
%doc doc/introspect.dtd doc/introspect.xsl doc/system-activation.txt
%{_datadir}/devhelp/books/dbus

%files devel
%defattr(-,root,root)
/%{_lib}/lib*.a
/%{_lib}/lib*.so
%dir %{_libdir}/dbus-1.0
%{_libdir}/dbus-1.0/include/
%{_libdir}/pkgconfig/dbus-1.pc
%{_includedir}/*

%changelog
* Thu Oct 16 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.2.4-1m)
- [SECURITY] CVE-2008-3834 version 1.2.4
- import increase-timeout.patch and re-import start-early.patch from Fedora
- remove fix_userdb_macro.patch

* Thu Sep 25 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.2.3-1m)
- update to 1.2.3
- comment out patch2

* Sat Jul 12 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.2.1-6m)
- own %%{_datadir}/dbus-1/services

* Sun May 25 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.2.1-5m)
- import fix_userdb_macro.patch from Fedora
 +* Fri May 05 2008 John (J5) Palmieri <johnp@redhat.com> - 1.2.1-2
 +- patch to enable dbus userdb caching as was the default in 1.0.x
 +- previous upstream commit had accidentally disabled it because
 +  of mispelled macro names - the non-cached codepath can cause
 +  a crash of the bus
 +- fd.o bug #15588 - https://bugs.freedesktop.org/show_bug.cgi?id=15588

* Sun May 11 2008 NARITA Koichi <pulsar@momonga-linux.org>
- (1.2.1-4m)
- rebuild against qt3 and qt-4.4.0-1m

* Sun Apr 20 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.2.1-3m)
- own %%{_datadir}/dbus-1/interfaces

* Sat Apr 19 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.2.1-2m)
- Pass 'dbus' instead of 81 as --with-dbus-user; otherwise the setuid
  system bus activation helper fails

* Mon Apr  7 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.2.1-1m)
- update 1.2.1

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.1.20-2m)
- rebuild against gcc43

* Sat Mar  1 2008 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.1.20-1m)
- update 1.1.20 (unstable)
- [SECURITY] CVE-2008-0595 (maybe)
- comment out patch3 patch4

* Mon Feb 25 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.1.4-2m)
- own %%{_sysconfdir}/dbus-1/session.d
- remove /%%{_lib}/*dbus-1*.so.* from dbus
- remove %%{_datadir}/devhelp/books/dbus from dbus-devel

* Sun Feb 24 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.1.4-1m)
- update 1.1.4(1.2.0-RC2)

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.2-8m)
- %%NoSource -> NoSource

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.2-7m)
- %%NoSource -> NoSource

* Sun Jun  3 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.2-6m)
- move prefix from /usr to /
- modify messagebus start time from 97 to 22
- sync with F-7

* Fri Apr 13 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.2-5m)
- import dbus-1.0.2-selinux.patch from Fedora
 +* Thu Apr 12 2007 David Zeuthen <davidz@redhat.com> - 1.0.2-3
 +- Start SELinux thread after setuid call (#221168)

* Mon Feb 26 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.2-4m)
- dbus-devel Requires: pkgconfig

* Wed Feb 14 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.2-3m)
- add PreReq initscripts

* Tue Feb  6 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.0.2-2m)
- update to 1.0.2 again
- update and apply dbus-0.61-selinux-avc-audit.patch again
- import dbus-0.92-audit-system.patch from Fedora Core devel
 +* Wed Sep 6 2006 Dan Walsh <dwalsh@redhat.com> - 0.92-2
 +- Only audit on the system bus

* Mon Feb  5 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.92-5m)
- roll back 0.92

* Mon Feb  5 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.0.2-1m)
- update to 1.0.2
- comment out patch2 (maybe needed)

* Mon Feb  4 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.92-4m)
- %%post used condrestart

* Sun Jan 21 2007 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.92-3m)
- [SECURITY] CVE-2006-6107
- import dbus-0.92-CVE-2006-6107.patch from Mandriva
 +* Mon Dec 18 2006 Vincent Danen <vdanen@mandriva.com> 0.92-8.2mdv2007.0
 +- P3: security fix for CVE-2006-6107

* Tue Sep  5 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.92-2m)
- fix %%post script

* Thu Aug 31 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.92-1m)
- update to 0.92
- delete packages dbus-glib dbus-qt dbus-python

* Sat Aug 26 2006 NARITA Koichi <pulsar@sea.plala.or.jp>
- (0.61-2m)
- rebuild against expat-2.0.0-1m

* Tue May  2 2006 Masaru SANUKI <sanuki@momonga-linux.org>
- (0.61-1m)
- version dbus-0.61

* Sun Feb 12 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.60-3m)
- enable audit

* Fri Dec 30 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.60-2m)
- enable Qt3 bindings

* Fri Dec 30 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (0.60-1m)
- sync with fc-devel
- disable audit

* Tue Nov  1 2005 Ichiro Nakai <ichiro@n.email.ne.jp>
- (0.50-3m)
- fix Source1: messagebus

* Tue Nov  1 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (0.50-2m)
- fix build error x86_64

* Sat Oct 29 2005 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (0.50-1m)
- version 0.50

* Thu Jan 20 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.22-2m)
- add Patch10:	dbus-initddir-bus-Makefile-01.patch
- delete --with-init-scripts=redhat from cflags

- (0.22-10m)
- import from FC3.

* Wed Oct 13 2004 John (J5) Palmieri <johnp@redhat.com>
- Bump up release and rebuild

* Mon Oct 11 2004 Tim Waugh <twaugh@redhat.com>
- Run /sbin/ldconfig for glib sub-package (bug #134062).

* Wed Sep 22 2004 John (J5) Palmieri <johnp@redhat.com>
- Fixed patch to use dbus-1 instead of dbus-1.0
- (configure.in): Exported just the datadir instead of
  the full path to the dbus datadir for consistency

* Wed Sep 22 2004 John (J5) Palmieri <johnp@redhat.com>
- Adding patch to move /usr/lib/dbus-1.0/services to
  /usr/share/dbus-1.0/services 

* Thu Sep 16 2004 John (J5) Palmieri <johnp@redhat.com>
- reverting BuildRequires: redhat-release because of issues with build system
- added precompiled version of the messagebus init script

* Thu Sep 16 2004 John (J5) Palmieri <johnp@redhat.com>
- changed /etc/redhat-release to the package redhat-release

* Thu Sep 16 2004 John (J5) Palmieri <johnp@redhat.com>
- added python int64 patch from davidz

* Thu Sep 16 2004 John (J5) Palmieri <johnp@redhat.com>
- added BuildRequires: /etc/redhat-release (RH Bug #132436)

* Wed Aug 18 2004 John (J5) Palmieri <johnp@redhat.com>
- Added Steve Grubb's spec file patch (RH Bug #130201)

* Mon Aug 16 2004 John (J5) Palmieri <johnp@redhat.com>
- Disabled dbus-gtk since dbus-viewer doesn't do anything right now

* Mon Aug 16 2004 John (J5) Palmieri <johnp@redhat.com>
- Moved dbus-viewer to new dbus-gtk package so that dbus-glib
  no longer requires X or GTK libraries. (RH Bug #130029)

* Thu Aug 12 2004 John (J5) Palmieri <johnp@redhat.com>
- Update to new 0.22 release

* Thu Aug 05 2004 John (J5) Palmieri <johnp@redhat.com> 
- Added BuildRequires for libselinux-devel and Requires for libselinux

* Tue Aug 02 2004 Colin Walters <walters@redhat.com>
- Add SE-DBus patch

* Fri Jul 30 2004 John (J5) Palmieri <johnp@redhat.com>
- Added lib64 workaround for python bindings installing to
  the wrong lib directory on 64 bit archs

* Fri Jul 30 2004 John (J5) Palmieri <johnp@redhat.com>
- Updated console-auth patch
- rebuild
 
* Thu Jul 22 2004 John (J5) Palmieri <johnp@redhat.com>
- Update to upstream CVS build
- Added console-auth patch

* Fri Jun 25 2004 John (J5) Palmieri <johnp@redhat.com>
- Workaround added to fix gcc-3.4 bug on ia64

* Fri Jun 25 2004 John (J5) Palmieri <johnp@redhat.com>
- require new Pyrex version and see if it builds this time

* Fri Jun 25 2004 John (J5) Palmieri <johnp@redhat.com>
- rebuild with updated Pyrex (0.9.2.1)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Jun 04 2004 John (J5) Palmieri <johnp@redhat.com>
- Moved dbus-viewer, dbus-monitor and dbus-glib-tool 
  into the dbus-glib package so that the main dbus
  package does not depend on glib (Bug #125285) 

* Thu Jun 03 2004 John (J5) Palmieri <johnp@redhat.com>
- rebuilt

* Thu May 27 2004 John (J5) Palmieri <johnp@redhat.com>
- added my Python patch
- took out the qt build requires
- added a gtk+ build requires 

* Fri Apr 23 2004 John (J5) Palmieri <johnp@redhat.com>
- Changed build requirement to version 0.9-3 of Pyrex
  to fix problem with builing on x86_64

* Tue Apr 20 2004 John (J5) Palmieri <johnp@redhat.com>
- update to upstream 0.21
- removed dbus-0.20-varargs.patch patch (fixed upstream)

* Mon Apr 19 2004 John (J5) Palmieri <johnp@redhat.com>
- added a dbus-python package to generate python bindings
- added Pyrex build dependacy

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Feb 25 2004 Bill Nottingham <notting@redhat.com> 0.20-4
- fix dbus error functions on x86-64 (#116324)
- add prereq (#112027)

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Tim Waugh <twaugh@redhat.com>
- Conflict with cups prior to configuration file change, so that the
  %%postun service condrestart works.

* Wed Feb 11 2004 Havoc Pennington <hp@redhat.com> 0.20-2
- rebuild in fc2, cups now updated

* Wed Jan  7 2004 Bill Nottingham <notting@redhat.com> 0.20-1
- update to upstream 0.20

* Thu Oct 16 2003 Havoc Pennington <hp@redhat.com> 0.13-6
- hmm, dbus doesn't support uids in the config file. fix.

* Thu Oct 16 2003 Havoc Pennington <hp@redhat.com> 0.13-5
- put uid instead of username in the config file, to keep things working with name change

* Thu Oct 16 2003 Havoc Pennington <hp@redhat.com> 0.13-4
- make subpackages require the specific release, not just version, of base package

* Thu Oct 16 2003 Havoc Pennington <hp@redhat.com> 0.13-3
- change system user "messagebus" -> "dbus" to be under 8 chars

* Mon Sep 29 2003 Havoc Pennington <hp@redhat.com> 0.13-2
- see if removing qt subpackage for now will get us through the build system,
  qt bindings not useful yet anyway

* Sun Sep 28 2003 Havoc Pennington <hp@redhat.com> 0.13-1
- 0.13 fixes a little security oops

* Mon Aug  4 2003 Havoc Pennington <hp@redhat.com> 0.11.91-3
- break the tiny dbus-launch that depends on X into separate package
  so a CUPS server doesn't need X installed

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Sat May 17 2003 Havoc Pennington <hp@redhat.com> 0.11.91-1
- 0.11.91 cvs snap properly merges system.d

* Fri May 16 2003 Havoc Pennington <hp@redhat.com> 0.11.90-1
- build a cvs snap with a few more fixes

* Fri May 16 2003 Havoc Pennington <hp@redhat.com> 0.11-2
- fix a crash that was breaking cups

* Thu May 15 2003 Havoc Pennington <hp@redhat.com> 0.11-1
- 0.11

* Thu May 15 2003 Havoc Pennington <hp@redhat.com> 0.10.90-1
- use rc.d/init.d not init.d, bug #90192
- include the new man pages

* Fri Apr 11 2003 Havoc Pennington <hp@redhat.com> 0.9-1
- 0.9
- export QTDIR explicitly
- re-enable qt, the problem was most likely D-BUS configure

* Tue Apr  1 2003 Havoc Pennington <hp@redhat.com> 0.6.94-1
- update from CVS with a fix to set uid after gid

* Tue Apr  1 2003 Havoc Pennington <hp@redhat.com> 0.6.93-1
- new cvs snap that actually forks to background and changes 
  user it's running as and so forth
- create our system user in pre

* Mon Mar 31 2003 Havoc Pennington <hp@redhat.com> 0.6.92-1
- fix for "make check" test that required a home directory

* Mon Mar 31 2003 Havoc Pennington <hp@redhat.com> 0.6.91-1
- disable qt for now because beehive hates me
- pull a slightly newer cvs snap that creates socket directory
- cat the make check log after make check fails

* Mon Mar 31 2003 Havoc Pennington <hp@redhat.com> 0.6.90-1
- initial build

